import request from '@/utils/request';
import type { ApiResult } from '@/api';
import type { Park, ParkParam } from './model';

/**
 * 获取列表
 * @param params
 */
export async function listParks(params?: ParkParam) {
  const res = await request.get<ApiResult<Park[]>>('/basic/park', {
    params
  });
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 * @param id
 */
export async function removePark(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/basic/park/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
/**
 * 添加
 */
export async function addPark(data: Park) {
  const res = await request.post<ApiResult<unknown>>('/basic/park', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 */
export async function updatePark(data: Park) {
  const res = await request.put<ApiResult<unknown>>('/basic/park', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}


// /**
//  * 修改状态
//  */
// export async function updateParkStatus(id?: number, right?: number) {
//   const res = await request.put<ApiResult<unknown>>(
//     '/basic/park/status',
//     {
//       id,
//       right
//     }
//   );
//   if (res.data.code === 0) {
//     return res.data.message;
//   }
//   return Promise.reject(new Error(res.data.message));
// }

/**
 * 检查用户是否存在
 */
export async function checkExistence(
  field: string,
  value: string,
  id?: number
) {
  const res = await request.get<ApiResult<unknown>>(
    '/basic/visitor/existence',
    {
      params: { field, value, id }
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
