import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Visitor, VisitorParam } from './model';

/**
 * 分页查询用户
 */
export async function pageVisitor(params: VisitorParam) {
  const res = await request.get<ApiResult<PageResult<Visitor>>>(
    '/basic/visitor/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加用户
 */
export async function addVisitor(data: Visitor) {
  const res = await request.post<ApiResult<unknown>>('/basic/visitor', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改用户
 */
export async function updateVisitor(data: Visitor) {
  const res = await request.put<ApiResult<unknown>>('/basic/visitor', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除用户
 */
export async function removeVisitor(id?: number) {
  const res = await request.delete<ApiResult<unknown>>(
    '/basic/visitor/' + id
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改用户状态
 */
export async function updateVisitorStatus(id?: number, right?: number) {
  const res = await request.put<ApiResult<unknown>>(
    '/basic/visitor/status',
    {
      id,
      right
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 检查用户是否存在
 */
export async function checkExistence(
  field: string,
  value: string,
  id?: number
) {
  const res = await request.get<ApiResult<unknown>>(
    '/basic/visitor/existence',
    {
      params: { field, value, id }
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
