import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Article, ArticleParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageArticle(params: ArticleParam) {
  const res = await request.get<ApiResult<PageResult<Article>>>(
    '/report/article/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 * @returns
 */
export async function addArticle(data: Article) {
  const res = await request.post<ApiResult<unknown>>('/report/article/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateArticle(data: Article) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/article/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeArticle(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/article/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeArticles(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/article/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateArticleStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/article/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
