import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Develop, DevelopParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageDevelop(params: DevelopParam) {
  const res = await request.get<ApiResult<PageResult<Develop>>>(
    '/report/develop/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 * @returns
 */
export async function addDevelop(data: Develop) {
  const res = await request.post<ApiResult<unknown>>('/report/develop/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateDevelop(data: Develop) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/develop/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeDevelop(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/develop/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeDevelops(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/develop/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateDevelopStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/develop/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
