import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { EcoCompany, EcoCompanyParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageEcoCompany(params: EcoCompanyParam) {
  const res = await request.get<ApiResult<PageResult<EcoCompany>>>(
    '/report/eco/company/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报
 * @returns
 */
export async function addEcoCompany(data: EcoCompany) {
  const res = await request.post<ApiResult<unknown>>(
    '/report/eco/company/add',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateEcoCompany(data: EcoCompany) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/company/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeEcoCompany(id?: number) {
  const res = await request.delete<ApiResult<unknown>>(
    '/report/eco/company/' + id
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeEcoCompanies(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>(
    '/report/eco/company/batch',
    {
      data
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateEcoCompanyStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/company/status',
    {
      id,
      status
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
