import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { EcoIncome, EcoIncomeParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageEcoIncome(params: EcoIncomeParam) {
  const res = await request.get<ApiResult<PageResult<EcoIncome>>>(
    '/report/eco/income/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报
 * @returns
 */
export async function addEcoIncome(data: EcoIncome) {
  const res = await request.post<ApiResult<unknown>>(
    '/report/eco/income/add',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateEcoIncome(data: EcoIncome) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/income/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeEcoIncome(id?: number) {
  const res = await request.delete<ApiResult<unknown>>(
    '/report/eco/income/' + id
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeEcoIncomes(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>(
    '/report/eco/income/batch',
    {
      data
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateEcoIncomeStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/income/status',
    {
      id,
      status
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
