import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { EcoInject, EcoInjectParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageEcoInject(params: EcoInjectParam) {
  const res = await request.get<ApiResult<PageResult<EcoInject>>>(
    '/report/eco/inject/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报
 * @returns
 */
export async function addEcoInject(data: EcoInject) {
  const res = await request.post<ApiResult<unknown>>(
    '/report/eco/inject/add',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateEcoInject(data: EcoInject) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/inject/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeEcoInject(id?: number) {
  const res = await request.delete<ApiResult<unknown>>(
    '/report/eco/inject/' + id
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeEcoInjects(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>(
    '/report/eco/inject/batch',
    {
      data
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateEcoInjectStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/inject/status',
    {
      id,
      status
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
