import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { EcoInvest, EcoInvestParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageEcoInvest(params: EcoInvestParam) {
  const res = await request.get<ApiResult<PageResult<EcoInvest>>>(
    '/report/eco/invest/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 * @returns
 */
export async function addEcoInvest(data: EcoInvest) {
  const res = await request.post<ApiResult<unknown>>('/report/eco/invest/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateEcoInvest(data: EcoInvest) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/invest/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeEcoInvest(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/invest/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeEcoInvests(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/invest/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateEcoInvestStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/eco/invest/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
