import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { EcoManu, EcoManuParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageEcoManu(params: EcoManuParam) {
  const res = await request.get<ApiResult<PageResult<EcoManu>>>(
    '/report/eco/manu/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 * @returns
 */
export async function addEcoManu(data: EcoManu) {
  const res = await request.post<ApiResult<unknown>>('/report/eco/manu/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateEcoManu(data: EcoManu) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/manu/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeEcoManu(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/manu/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeEcoManus(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/manu/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateEcoManuStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/eco/manu/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
