import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type {
  EcoProject,
  EcoProjectParam,
} from './model';


/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageEcoProject(params: EcoProjectParam) {
  const res = await request.get<ApiResult<PageResult<EcoProject>>>(
    '/report/eco/project/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报
 * @returns
 */
export async function addEcoProject(data: EcoProject) {
  const res = await request.post<ApiResult<unknown>>('/report/eco/project/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateEcoProject(data: EcoProject) {
  const res = await request.put<ApiResult<unknown>>('/report/eco/project/update', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeEcoProject(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/project/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeEcoProjects(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/project/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateEcoProjectStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/eco/project/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
