import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { EcoService, EcoServiceParam } from './model';


/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageEcoService(params: EcoServiceParam) {
  const res = await request.get<ApiResult<PageResult<EcoService>>>(
    '/report/eco/service/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 * @returns
 */
export async function addEcoService(data: EcoService) {
  const res = await request.post<ApiResult<unknown>>('/report/eco/service/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateEcoService(data: EcoService) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/service/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeEcoService(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/service/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeEcoServices(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/service/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateEcoServiceStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/eco/service/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
