import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { EcoTech, EcoTechParam } from './model';


/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageEcoTech(params: EcoTechParam) {
  const res = await request.get<ApiResult<PageResult<EcoTech>>>(
    '/report/eco/tech/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 * @returns
 */
export async function addEcoTech(data: EcoTech) {
  const res = await request.post<ApiResult<unknown>>('/report/eco/tech/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateEcoTech(data: EcoTech) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/eco/tech/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeEcoTech(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/tech/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeEcoTechs(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/eco/tech/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateEcoTechStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/eco/tech/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
