import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Innovate, InnovateParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageInnovate(params: InnovateParam) {
  const res = await request.get<ApiResult<PageResult<Innovate>>>(
    '/report/innovate/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报综述
 * @returns
 */
export async function addInnovate(data: Innovate) {
  const res = await request.post<ApiResult<unknown>>('/report/innovate/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateInnovate(data: Innovate) {
  const res = await request.put<ApiResult<unknown>>('/report/innovate/update', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeInnovate(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/innovate/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeInnovates(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/innovate/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateInnovateStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/innovate/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
