import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Invest, InvestParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageInvest(params: InvestParam) {
  const res = await request.get<ApiResult<PageResult<Invest>>>(
    '/report/invest/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 * @returns
 */
export async function addInvest(data: Invest) {
  const res = await request.post<ApiResult<unknown>>('/report/invest/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateInvest(data: Invest) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/invest/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeInvest(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/invest/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeInvests(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/invest/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateInvestStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/invest/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
