import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type {
  Party,
  PartyParam,
} from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageParty(params: PartyParam) {
  const res = await request.get<ApiResult<PageResult<Party>>>(
    '/report/party/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报综述
 * @returns
 */
export async function addParty(data: Party) {
  const res = await request.post<ApiResult<unknown>>('/report/party/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateParty(data: Party) {
  const res = await request.put<ApiResult<unknown>>('/report/party/update', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeParty(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/party/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeParties(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/party/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updatePartyStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/party/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
