import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type {
  Project,
  ProjectParam,
} from './model';


/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageProject(params: ProjectParam) {
  const res = await request.get<ApiResult<PageResult<Project>>>(
    '/report/project/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报
 * @returns
 */
export async function addProject(data: Project) {
  const res = await request.post<ApiResult<unknown>>('/report/project/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateProject(data: Project) {
  const res = await request.put<ApiResult<unknown>>('/report/project/update', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeProject(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/project/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeProjects(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/project/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateProjectStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/project/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
