import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Service, ServiceParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageService(params: ServiceParam) {
  const res = await request.get<ApiResult<PageResult<Service>>>(
    '/report/service/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 * @returns
 */
export async function addService(data: Service) {
  const res = await request.post<ApiResult<unknown>>('/report/service/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateService(data: Service) {
  const res = await request.put<ApiResult<unknown>>(
    '/report/service/update',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeService(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/service/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeServices(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/service/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateServiceStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/service/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
