import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Stable, StableParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageStable(params: StableParam) {
  const res = await request.get<ApiResult<PageResult<Stable>>>(
    '/report/stable/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报综述
 * @returns
 */
export async function addStable(data: Stable) {
  const res = await request.post<ApiResult<unknown>>('/report/stable/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateStable(data: Stable) {
  const res = await request.put<ApiResult<unknown>>('/report/stable/update', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeStable(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/stable/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeStables(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/stable/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateStableStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/stable/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
