import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Tax, TaxParam } from './model';

/**
 * 分页获取
 * @param params
 * @returns
 */
export async function pageTax(params: TaxParam) {
  const res = await request.get<ApiResult<PageResult<Tax>>>(
    '/report/tax/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 填报综述
 * @returns
 */
export async function addTax(data: Tax) {
  const res = await request.post<ApiResult<unknown>>('/report/tax/add', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 * @param data
 * @returns
 */
export async function updateTax(data: Tax) {
  const res = await request.put<ApiResult<unknown>>('/report/tax/update', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeTax(id?: number) {
  const res = await request.delete<ApiResult<unknown>>('/report/tax/' + id);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeTaxes(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>('/report/tax/batch', {
    data
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改状态
 * @param id
 * @param status
 * @returns
 */
export async function updateTaxStatus(id?: number, status?: number) {
  const res = await request.put<ApiResult<unknown>>('/report/tax/status', {
    id,
    status
  });
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
