import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Depart, DepartParam } from './model';

/**
 * 分页查询机构
 */
export async function pageDeparts(params: DepartParam) {
  const res = await request.get<ApiResult<PageResult<Depart>>>(
    '/system/depart/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 查询机构列表
 */
export async function listDeparts(params?: DepartParam) {
  const res = await request.get<ApiResult<Depart[]>>(
    '/system/depart',
    { params }
  );
  if (res.data.code === 0 && res.data.data) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加机构
 */
export async function addDepart(data: Depart) {
  const res = await request.post<ApiResult<unknown>>(
    '/system/depart',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改机构
 */
export async function updateDepart(data: Depart) {
  const res = await request.put<ApiResult<unknown>>(
    '/system/depart',
    data
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除机构
 */
export async function removeDepart(id?: number) {
  const res = await request.delete<ApiResult<unknown>>(
    '/system/depart/' + id
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
